# Changelog

## 0.15.0-alpha (2025-01-24)

Full Changelog: [v0.14.0-alpha...v0.15.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.14.0-alpha...v0.15.0-alpha)

### Features

* **api:** update via SDK Studio ([#49](https://github.com/rajatb94/walledai-python/issues/49)) ([d3d3fcd](https://github.com/rajatb94/walledai-python/commit/d3d3fcd85ac4d205437d590469614f40949fe158))

## 0.14.0-alpha (2024-05-15)

Full Changelog: [v0.13.0-alpha...v0.14.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.13.0-alpha...v0.14.0-alpha)

### Features

* **api:** update via SDK Studio ([#46](https://github.com/rajatb94/walledai-python/issues/46)) ([c9de5bf](https://github.com/rajatb94/walledai-python/commit/c9de5bfcd6001019ed8b8e4acef14cecbc851124))

## 0.13.0-alpha (2024-05-15)

Full Changelog: [v0.12.0-alpha...v0.13.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.12.0-alpha...v0.13.0-alpha)

### Features

* **api:** update via SDK Studio ([#42](https://github.com/rajatb94/walledai-python/issues/42)) ([8462b94](https://github.com/rajatb94/walledai-python/commit/8462b944d423ef2dadcf17891219784ef735dc50))
* **api:** update via SDK Studio ([#44](https://github.com/rajatb94/walledai-python/issues/44)) ([4e3235b](https://github.com/rajatb94/walledai-python/commit/4e3235bd3db5a40adf9898c2d7bcc3a166609164))

## 0.12.0-alpha (2024-05-15)

Full Changelog: [v0.11.0-alpha...v0.12.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.11.0-alpha...v0.12.0-alpha)

### Features

* **api:** update via SDK Studio ([#39](https://github.com/rajatb94/walledai-python/issues/39)) ([8c5dac2](https://github.com/rajatb94/walledai-python/commit/8c5dac2ef7597eb403038fb6024c84cb50c840a3))

## 0.11.0-alpha (2024-05-15)

Full Changelog: [v0.10.0-alpha...v0.11.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.10.0-alpha...v0.11.0-alpha)

### Features

* **api:** update via SDK Studio ([#36](https://github.com/rajatb94/walledai-python/issues/36)) ([21b3bd0](https://github.com/rajatb94/walledai-python/commit/21b3bd01e2ed4db1713578a523a6828d352df441))

## 0.10.0-alpha (2024-05-15)

Full Changelog: [v0.9.0-alpha...v0.10.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.9.0-alpha...v0.10.0-alpha)

### Features

* **api:** update via SDK Studio ([#33](https://github.com/rajatb94/walledai-python/issues/33)) ([ff8031d](https://github.com/rajatb94/walledai-python/commit/ff8031dba7a2ebdffe89eb786b56bb63379c1ecd))

## 0.9.0-alpha (2024-05-15)

Full Changelog: [v0.8.0-alpha...v0.9.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.8.0-alpha...v0.9.0-alpha)

### Features

* **api:** update via SDK Studio ([#30](https://github.com/rajatb94/walledai-python/issues/30)) ([f5390d7](https://github.com/rajatb94/walledai-python/commit/f5390d73a207ddd8adb6d9194712e49f1fd3ce5e))

## 0.8.0-alpha (2024-05-15)

Full Changelog: [v0.7.0-alpha...v0.8.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.7.0-alpha...v0.8.0-alpha)

### Features

* **api:** update via SDK Studio ([#27](https://github.com/rajatb94/walledai-python/issues/27)) ([725419a](https://github.com/rajatb94/walledai-python/commit/725419ae30876523709a6ad1cade2b9c07fd6d9d))

## 0.7.0-alpha (2024-05-14)

Full Changelog: [v0.6.0-alpha...v0.7.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.6.0-alpha...v0.7.0-alpha)

### Features

* **api:** update via SDK Studio ([#24](https://github.com/rajatb94/walledai-python/issues/24)) ([a0d5993](https://github.com/rajatb94/walledai-python/commit/a0d5993d77e9e9753f2c52e53c73da1613303602))

## 0.6.0-alpha (2024-05-14)

Full Changelog: [v0.5.0-alpha...v0.6.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.5.0-alpha...v0.6.0-alpha)

### Features

* **api:** update via SDK Studio ([#20](https://github.com/rajatb94/walledai-python/issues/20)) ([7c61ec4](https://github.com/rajatb94/walledai-python/commit/7c61ec455aa353e983342c98a4b1878625abfd1c))
* **api:** update via SDK Studio ([#22](https://github.com/rajatb94/walledai-python/issues/22)) ([90da5a1](https://github.com/rajatb94/walledai-python/commit/90da5a15e301a12fd8fd9ca2f01afdcae7fa4c9f))

## 0.5.0-alpha (2024-05-14)

Full Changelog: [v0.4.0-alpha...v0.5.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.4.0-alpha...v0.5.0-alpha)

### Features

* **api:** update via SDK Studio ([bb9e474](https://github.com/rajatb94/walledai-python/commit/bb9e4742269966e767fa455831bb645090ead925))
* **api:** update via SDK Studio ([#16](https://github.com/rajatb94/walledai-python/issues/16)) ([1b75418](https://github.com/rajatb94/walledai-python/commit/1b75418b401ed9e85a240a951cfe48cd27fa930e))
* **api:** update via SDK Studio ([#18](https://github.com/rajatb94/walledai-python/issues/18)) ([56717ce](https://github.com/rajatb94/walledai-python/commit/56717cea3d8bc80e3582a0c6e441af09d761967e))

## 0.4.0-alpha (2024-05-14)

Full Changelog: [v0.3.0-alpha...v0.4.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.3.0-alpha...v0.4.0-alpha)

### Features

* **api:** update via SDK Studio ([#13](https://github.com/rajatb94/walledai-python/issues/13)) ([6e15919](https://github.com/rajatb94/walledai-python/commit/6e15919ad8ba5c0a52a0deeacc4b4aeec453aef2))

## 0.3.0-alpha (2024-05-14)

Full Changelog: [v0.2.0-alpha...v0.3.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.2.0-alpha...v0.3.0-alpha)

### Features

* **api:** update via SDK Studio ([#11](https://github.com/rajatb94/walledai-python/issues/11)) ([fb7e370](https://github.com/rajatb94/walledai-python/commit/fb7e3704cb5b08f6bd51ef3c714f9cb13c8949e7))
* **api:** update via SDK Studio ([#9](https://github.com/rajatb94/walledai-python/issues/9)) ([571e707](https://github.com/rajatb94/walledai-python/commit/571e7070a8bbc21703478b8bb4485ebadaedd928))

## 0.2.0-alpha (2024-05-14)

Full Changelog: [v0.1.0-alpha...v0.2.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.1.0-alpha...v0.2.0-alpha)

### Features

* **api:** update via SDK Studio ([#6](https://github.com/rajatb94/walledai-python/issues/6)) ([6d21723](https://github.com/rajatb94/walledai-python/commit/6d217235ea9616c46c3c2ea3e6bba97ace2b24ad))

## 0.1.0-alpha (2024-05-13)

Full Changelog: [v0.0.1-alpha...v0.1.0-alpha](https://github.com/rajatb94/walledai-python/compare/v0.0.1-alpha...v0.1.0-alpha)

### Features

* **api:** update via SDK Studio ([#4](https://github.com/rajatb94/walledai-python/issues/4)) ([067d93e](https://github.com/rajatb94/walledai-python/commit/067d93e14b0b46e44bfde80a4a7fc0da374565bd))

## 0.0.1-alpha (2024-05-13)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha](https://github.com/rajatb94/walledai-python/compare/v0.0.1-alpha.0...v0.0.1-alpha)

### Features

* **api:** update via SDK Studio ([0db116f](https://github.com/rajatb94/walledai-python/commit/0db116f19d228a34ca1053189e17b717e85809ba))
* **api:** update via SDK Studio ([1f830e7](https://github.com/rajatb94/walledai-python/commit/1f830e71ac3b6091da444174838403a29f781908))


### Chores

* configure new SDK language ([4a873a4](https://github.com/rajatb94/walledai-python/commit/4a873a4bd7d50220647023266f713e0da34542ac))
* go live ([#1](https://github.com/rajatb94/walledai-python/issues/1)) ([7d01dd9](https://github.com/rajatb94/walledai-python/commit/7d01dd93665791b9361d6e3c89a89645eb772a83))
